@@ -389,10 +389,11 @@ list_from_string (const gchar *str)
 
   g_return_val_if_fail (str != NULL, NULL);
   g_return_val_if_fail (str[0] == '[', NULL);
-  g_return_val_if_fail (str[g_utf8_strlen (str, -1) - 1] == ']', NULL);
+  g_return_val_if_fail (str[strlen (str) - 1] == ']', NULL);
 
   txt = g_strdup (str + 1); /* get the '[' out of the way */
-  txt[g_utf8_strlen (txt, -1) - 1] = 0; /* get the ']' out of the way */
+  txt[strlen (txt) - 1] = 0; /* get the ']' out of the way */
+
 
   if (txt[0] == 0) { /* handle the empty list */
     g_free (txt);
@@ -406,15 +407,15 @@ list_from_string (const gchar *str)
     if (item == NULL)
       item = g_string_new ("");
 
-    if ((*tmp_list)[g_utf8_strlen (*tmp_list, -1) - 1] == '\\') {
+    if ((*tmp_list)[strlen (*tmp_list) - 1] == '\\') {
 
       g_string_append_len (item, *tmp_list,
-			   g_utf8_strlen (*tmp_list, -1) - 1);
+			   strlen (*tmp_list) - 1);
       must_concat = TRUE;
     } else {
 
       g_string_append_len (item, *tmp_list,
-			   g_utf8_strlen (*tmp_list, -1));
+			   strlen (*tmp_list));
       must_concat = FALSE;
     }
 
@@ -437,6 +438,7 @@ list_from_string (const gchar *str)
     item = NULL;
   }
 
+    
   return result;
 }
 
@@ -1178,17 +1180,19 @@ saveconf_timer_callback (gpointer unused)
 void 
 gm_conf_init (int argc, char **argv)
 {
+  gboolean result = FALSE;
   DataBase *db = database_get_default ();
  
-  if (!gm_conf_load_user_conf (db))
-    if (!gm_conf_load_sys_conf (db))
-      g_warning ("Couldn't load system configuration");
+  result = gm_conf_load_sys_conf (db);
+  result = (gm_conf_load_user_conf (db) || result);
+  if (!result)
+    g_warning ("Couldn't load system configuration");
 
   /* those keys aren't found in gnomemeeting's schema */
   gm_conf_set_bool ("/desktop/gnome/interface/menus_have_icons", TRUE);
 
   /* automatic savings */
-  g_timeout_add (120000, (GSourceFunc)saveconf_timer_callback, NULL);
+  g_timeout_add (5000, (GSourceFunc)saveconf_timer_callback, NULL);
 
 }
 
